@@ -3,7 +3,14 @@ from opnsense_cli.api.plugin.haproxy import Settings, Service
 
 
 class HaproxyServerFacade(HaproxyFacade):
+    jsonpath_base = '$.haproxy.servers.server'
+    uuid_resolver_map = {
+        'linkedResolver': {'template': '$.haproxy.resolvers.resolver[{uuids}].name', 'insert_as_key': 'Resolver'},
+    }
+
     def __init__(self, settings_api: Settings, service_api: Service):
+        super().__init__()
+        self._complete_model_data_cache = None
         self._settings_api = settings_api
         self._service_api = service_api
 
@@ -16,13 +23,7 @@ class HaproxyServerFacade(HaproxyFacade):
         return server
 
     def _get_servers_list(self):
-        complete_model_data = self._settings_api.get()
-        jsonpath_base = '$.haproxy.servers.server'
-        uuid_resolver_map = {
-            'linkedResolver': {'template': '$.haproxy.resolvers.resolver[{uuids}].name', 'insert_as_key': 'Resolver'},
-        }
-
-        return self._api_mutable_model_get(complete_model_data, jsonpath_base, uuid_resolver_map)
+        return self._api_mutable_model_get(self._complete_model_data, self.jsonpath_base, self.uuid_resolver_map)
 
     def create_server(self, json_payload: dict):
         result = self._settings_api.addServer(json=json_payload)
